This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

libobjc - tiny tidyup


Committed to trunk

Thanks

--- ChangeLog   (revision 164198)
+++ ChangeLog   (working copy)
@@ -1,5 +1,9 @@
 2010-09-10  Nicola Pero  <nicola.pero@meta-innovation.com>
 
+       * objc/objc-api.h (objc_trace): Unused variable removed.
+
+2010-09-10  Nicola Pero  <nicola.pero@meta-innovation.com>
+
        * objc/deprecated: New directory.
        * objc/deprecated/README: New file.
        * objc/README: New file.
Index: objc/objc-api.h
===================================================================
--- objc/objc-api.h     (revision 164198)
+++ objc/objc-api.h     (working copy)
@@ -133,11 +133,7 @@
 
 #define OBJC_ERR_BAD_STATE 40          /* Bad thread state */
 
-/* Set this variable nonzero to print a line describing each
-   message that is sent.  (this is currently disabled)  */
-extern BOOL objc_trace;
 
-
 /* For every class which happens to have statically allocated instances in
    this module, one OBJC_STATIC_INSTANCES is allocated by the compiler.
    INSTANCES is NULL terminated and points to all statically allocated
@@ -186,18 +182,18 @@
 ** That array holds a pointer to each module structure of the executable. 
 */
 typedef struct objc_module {
-  unsigned long version;                        /* Compiler revision. */
-  unsigned long size;                           /* sizeof(Module). */
-  const char* name;                             /* Name of the file where the 
-                                                  module was generated.   The 
-                                                  name includes the path. */
-
-  Symtab_t    symtab;                           /* Pointer to the Symtab of
-                                                  the module.  The Symtab
-                                                  holds an array of 
-                                                 pointers to 
-                                                  the classes and categories 
-                                                  defined in the module. */
+  unsigned long version; /* Version of the Module data structure.  */
+  unsigned long size;    /* sizeof(Module) according to the compiler -
+                           only used to sanity check that it matches
+                           sizeof(Module) according to the
+                           runtime.  */
+  const char* name;      /* Name of the file used to compile the
+                           module - not set by modern compilers for
+                           security reasons.  */
+  Symtab_t    symtab;    /* Pointer to the Symtab of the module.  The
+                           Symtab holds an array of pointers to the
+                           classes and categories defined in the
+                           module. */
 } Module, *Module_t;



Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]